# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                      EPSILON                     #############################
#############################                Reader_Epsilon_PIV                #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads the variables from the output of
"Epsilon_PIV" source.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## EPSILON PIV READER FUNCTION #######################################
############################################################################################################

def Reader_Epsilon_PIV(INPUT):
	
	# Reading aero data from Fluent file:
	POINTS = INPUT.Points   										# It takes the points coordinates
	Vx = INPUT.PointData["Vx"]                              		# X-velocity component [m/s]
	Vy = INPUT.PointData["Vy"]                              		# Y-velocity component [m/s]	
	Vz = INPUT.PointData["Vz"]										# Z-velocity component [m/s]
	V = algs.sqrt(Vx**2+Vy**2+Vz**2)
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			    # Velocity vector in the mesh reference frame [m/s]
	V_star = INPUT.PointData["V_star"]
	
	
	Ps = 'None' 											        # No static pressure data is provided by experimental data	
	Rho = 'None' 											        # No density data is provided by experimental data
	MU_LAM = 'None' 											    # No viscosity data is provided by experimental data
	MU_TURB = 'None'  											    # No turbulence data is provided by experimental data
	
	
	# Read static temperature data:
	if INPUT.GetPointData().HasArray("Ts")==1:                      # This check if "Ts" array exists at the input 
		Ts = INPUT.PointData["Ts"]                   
	else:
		Ts = 'None'        	
	
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("Vorticity")==1:               # This check if "VORTICITY" array exists at the input 
		VORTICITY = INPUT.PointData["Vorticity"]                    # Vorticity vector in the mesh reference frame [1/s]
	else:
		VORTICITY = 'None'                           				 
	
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY,V_star