
# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################             Reader_Epsilon_Wake_Survey           #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads the variables from the output of
Reader_Epsilon_Wake_Survey.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
################################### EPSILON WAKE SURVEY READER FUNCTION ####################################
############################################################################################################

def Reader_Epsilon_Wake_Survey(INPUT):
	
	# Reading aero data from Fluent file:
	POINTS = INPUT.Points   										# It takes the points coordinates
	Vector_Speed = INPUT.PointData["Velocity"]
	Vx = INPUT.PointData["Velocity"][:,0]                           # X-velocity component [m/s]
	Vy = INPUT.PointData["Velocity"][:,1]                           # Y-velocity component [m/s]	
	Vz = INPUT.PointData["Velocity"][:,2]						    # Z-velocity component [m/s]
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			    # Velocity vector in the mesh reference frame [m/s]
	
	# Read static pressure data:
	if INPUT.GetPointData().HasArray("Ps")==1:                      # This check if "Ps" array exists at the input 
		Ps = INPUT.PointData["Ps"]               
	else:
		Ps = 'None'

	# Read total pressure data:
	if INPUT.GetPointData().HasArray("Pt")==1:                      # This check if "Pt" array exists at the input 
		Pt = INPUT.PointData["Pt"]               
	else:
		Pt = 'None'
        
	# Read static temperature data:
	if INPUT.GetPointData().HasArray("Ts")==1:                      # This check if "Ts" array exists at the input 
		Ts = INPUT.PointData["Ts"]               
	else:
		Ts = 'None'        

	# Read static temperature data:
	if INPUT.GetPointData().HasArray("Rho")==1:                      # This check if "Rho" array exists at the input 
		Rho = INPUT.PointData["Rho"]               
	else:
		Rho = 'None'    
       
        
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("VORTICITY")==1:               # This check if "VORTICITY" array exists at the input 
		VORTICITY = INPUT.PointData["VORTICITY"]                    # Vorticity vector in the mesh reference frame [1/s]
	else:
		VORTICITY = 'None'                           				 

	MU_LAM = 'None' 											    # No viscosity data is provided by experimental data
	MU_TURB = 'None'  											    # No turbulence data is provided by experimental data
	
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY,Pt