# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                    IC3 reader                    #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from IC3 CFD solver


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
############################################ NEW READER FUNCTION ###########################################
############################################################################################################

def Reader_IC3(INPUT):
	
	POINTS = INPUT.Points   																	# It takes the points coordinates
	Velocity_Vector = INPUT.PointData["U"] 													    # Velocity vector [m/s]
	Ps = INPUT.PointData["P"]                                                                   # Static pressure [Pa]
	Rho = INPUT.PointData["RHO"]                                						        # Density [Kg/m^3]
	Ts = INPUT.PointData["T"]
	MU_LAM = 'None'    

		
	# Reads turbulent viscosity data:
	if INPUT.GetPointData().HasArray("MU_SGS")==0:  
		MU_TURB = 'None'
	else:
		MU_TURB = INPUT.PointData["MU_SGS"]                            						    # Turbulent viscosity [Kg/m*s]	
	
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("VORT")==0:                                       	        # This check if "VORTICITY" array does not exists in the input 
		VORTICITY = 'None' 
	else:
		VORTICITY = INPUT.PointData["VORT"]                                                     # Vorticity vector in the mesh reference frame [1/s]
	
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY