# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################             LabView 5HP ISAE reader              #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Wake Survey" plugin that reads data from a LabView ".moy" file.
The output is a list with the headers and another list with the data (arranged in a matrix-shape)


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
#################################### PIV DANTEC TECPLOT READER FUNCTION ####################################
############################################################################################################

############################################################################################################
############################################### IMPORT MODULES #############################################
############################################################################################################


import os
import re
#import pandas as pd
#pd.core.format.header_style = None
import numpy as np




############################################################################################################
###############################################   INPUT DATA   #############################################
############################################################################################################



# CONSTANTS:
IgnoreFirstLine = 1   					# 0=no   1=yes   (ignore the first line of data, that is usually taken on wind-off conditions)



############################################################################################################
############################################ LABVIEW FILE PARSER ###########################################
############################################################################################################

def Reader_Labview_5HP_ISAE(filepath):                                           # This creates an array containing only the interesting measurements from the LabView file
	import numpy as np
	
	DATA = []                                                                   # create an empty list to collect the data
	Headers = []                                                                # The header names are kept for the file parsing, but changed later in the "CALCULATIONS" section

	with open(filepath, 'r') as file_object:                                    # open the file and read through it line by line
		line = file_object.readline()                                           # It reads the first line of data

		while line:

			line = line.replace('\xe9','e')                                     # It replaces the "é" character by an "e"
			line = line.replace('Delta PT0_moy.','Delta_PT0_moy.')              # it replaces the espaces by underscore in the some variable names       
			line = line.replace('Delta PT0_ecart','Delta_PT0_ecart')            
			line = line.replace('Delta P0_moy.','Delta_P0_moy.')             
			line = line.replace('Delta P0_ecart','Delta_P0_ecart')             
			line = line.replace('Alfa (Filtre)_moy.','Alfa_(Filtre)_moy.')
			line = line.replace('Alfa (Filtre)_ecart','Alfa_(Filtre)_ecart')
			line = line.replace('Delta PT0 (Filtre)_moy.','Delta_PT0_(Filtre)_moy.')
			line = line.replace('Delta PT0 (Filtre)_ecart','Delta_PT0_(Filtre)_ecart')
			line = line.replace('Delta P0 (Filtre)_moy.','Delta_P0_(Filtre)_moy.')
			line = line.replace('Delta P0 (Filtre)_ecart','Delta_P0_(Filtre)_ecart')
			line = line.replace('Tt0 (Filtre)_moy.','Tt0')
			line = line.replace('Tt0 (Filtre)_ecart','Tt0_(Filtre)_ecart')
			line = line.replace('RPM1 (Filtre)_moy.','RPM1_(Filtre)_moy.')
			line = line.replace('RPM1 (Filtre)_ecart','RPM1_(Filtre)_ecart')
			line = line.replace('RPM2 (Filtre)_moy.','RPM2_(Filtre)_moy.')
			line = line.replace('RPM2 (Filtre)_ecart','RPM2_(Filtre)_ecart')
			line = line.replace('RPM3 (Filtre)_moy.','RPM3_(Filtre)_moy.')
			line = line.replace('RPM3 (Filtre)_ecart','RPM3_(Filtre)_ecart')
			line = line.replace('RPM4 (Filtre)_moy.','RPM4_(Filtre)_moy.')
			line = line.replace('RPM4 (Filtre)_ecart','RPM4_(Filtre)_ecart')
			line = line.replace('V1 (Filtre)_moy.','V1_(Filtre)_moy.')
			line = line.replace('V1 (Filtre)_ecart','V1_(Filtre)_ecart')
			line = line.replace('V2 (Filtre)_moy.','V2_(Filtre)_moy.')
			line = line.replace('V2 (Filtre)_ecart','V2_(Filtre)_ecart')
			line = line.replace('V3 (Filtre)_moy.','V3_(Filtre)_moy.')
			line = line.replace('V3 (Filtre)_ecart','V3_(Filtre)_ecart')
			line = line.replace('V4 (Filtre)_moy.','V4_(Filtre)_moy.')
			line = line.replace('V4 (Filtre)_ecart','V4_(Filtre)_ecart')
			line = line.replace('I1 (Filtre)_moy.','I1_(Filtre)_moy.')
			line = line.replace('I1 (Filtre)_ecart','I1_(Filtre)_ecart')
			line = line.replace('I2 (Filtre)_moy.','I2_(Filtre)_moy.')
			line = line.replace('I2 (Filtre)_ecart','I2_(Filtre)_ecart')
			line = line.replace('I3 (Filtre)_moy.','I3_(Filtre)_moy.')
			line = line.replace('I3 (Filtre)_ecart','I3_(Filtre)_ecart')
			line = line.replace('I4 (Filtre)_moy.','I4_(Filtre)_moy.')
			line = line.replace('I4 (Filtre)_ecart','I4_(Filtre)_ecart')
			line = line.replace('Fw_x (Filtre)_moy.','Fw_x_(Filtre)_moy.')
			line = line.replace('Fw_x (Filtre)_ecart','Fw_x_(Filtre)_ecart')
			line = line.replace('Fw_y (Filtre)_moy.','Fw_y_(Filtre)_moy.')
			line = line.replace('Fw_y (Filtre)_ecart','Fw_y_(Filtre)_ecart')
			line = line.replace('Fw_z (Filtre)_moy.','Fw_z_(Filtre)_moy.')
			line = line.replace('Fw_z (Filtre)_ecart','Fw_z_(Filtre)_ecart')
			line = line.replace('Mw_x (Filtre)_moy.','Mw_x_(Filtre)_moy.')
			line = line.replace('Mw_x (Filtre)_ecart','Mw_x_(Filtre)_ecart')
			line = line.replace('Mw_y (Filtre)_moy.','Mw_y_(Filtre)_moy.')
			line = line.replace('Mw_y (Filtre)_ecart','Mw_y_(Filtre)_ecart')
			line = line.replace('Mw_z (Filtre)_moy.','Mw_z_(Filtre)_moy.')
			line = line.replace('Mw_z (Filtre)_ecart','Mw_z_(Filtre)_ecart')
			line = line.replace('Fn_x (Filtre)_moy.','Fn_x_(Filtre)_moy.')
			line = line.replace('Fn_x (Filtre)_ecart','Fn_x_(Filtre)_ecart')
			line = line.replace('Fn_y (Filtre)_moy.','Fn_y_(Filtre)_moy.')
			line = line.replace('Fn_y (Filtre)_ecart','Fn_y_(Filtre)_ecart')
			line = line.replace('Fn_z (Filtre)_moy.','Fn_z_(Filtre)_moy.')
			line = line.replace('Fn_z (Filtre)_ecart','Fn_z_(Filtre)_ecart')
			line = line.replace('Mn_x (Filtre)_moy.','Mn_x_(Filtre)_moy.')
			line = line.replace('Mn_x (Filtre)_ecart','Mn_x_(Filtre)_ecart')
			line = line.replace('Mn_y (Filtre)_moy.','Mn_y_(Filtre)_moy.')
			line = line.replace('Mn_y (Filtre)_ecart','Mn_y_(Filtre)_ecart')
			line = line.replace('Mn_z (Filtre)_moy.','Mn_z_(Filtre)_moy.')
			line = line.replace('Mn_z (Filtre)_ecart','Mn_z_(Filtre)_ecart')
			line = line.replace('Pa (Filtre)_moy.','Pa')
			line = line.replace('Pa (Filtre)_ecart','Pa_(Filtre)_ecart')
			line = line.replace('P1 (Filtre)_moy.','P1')
			line = line.replace('P1 (Filtre)_ecart','P1_STD')
			line = line.replace('P2 (Filtre)_moy.','P2')
			line = line.replace('P2 (Filtre)_ecart','P2_STD')
			line = line.replace('P3 (Filtre)_moy.','P3')
			line = line.replace('P3 (Filtre)_ecart','P3_STD')
			line = line.replace('P4 (Filtre)_moy.','P4')
			line = line.replace('P4 (Filtre)_ecart','P4_STD')
			line = line.replace('P5 (Filtre)_moy.','P5')
			line = line.replace('P5 (Filtre)_ecart','P5_STD')
			line = line.replace('Tsonde (Filtre)_moy.','Tsonde_(Filtre)_moy.')
			line = line.replace('Tsonde (Filtre)_ecart','Tsonde_(Filtre)_ecart')

			line = line.replace('Vmag_ext_data_moy.','Velocity_magnitude')			
			line = line.replace('U_ext_data_moy.','Vx')
			line = line.replace('U_ext_data_ecart','Vx_STD')
			line = line.replace('V_ext_data_moy.','Vy')
			line = line.replace('V_ext_data_ecart','Vy_STD')
			line = line.replace('W_ext_data_moy.','Vz')
			line = line.replace('W_ext_data_ecart','Vz_STD')
			line = line.replace('Ptot_ext_data_moy.','Pt')
			line = line.replace('Ptot_ext_data_ecart','Pt_STD')
			line = line.replace('Ps_ext_data_moy.','Ps')
			line = line.replace('Ps_ext_data_ecart','Ps_STD')
			line = line.replace('Ttot_ext_data_moy.','Tt')
			line = line.replace('Ttot_ext_data_ecart','Tt_STD')
			line = line.replace('Alpha_ext_data_moy.','5HP_Alpha')
			line = line.replace('Alpha_ext_data_ecart','5HP_Alpha_STD')
			line = line.replace('Beta_ext_data_moy.','5HP_Beta')
			line = line.replace('Beta_ext_data_ecart','5HP_Beta_STD')
			line = line.replace('cX_ext_data_moy.','X')
			line = line.replace('cX_ext_data_ecart','X_STD')
			line = line.replace('cY_ext_data_moy.','Y')
			line = line.replace('cY_ext_data_ecart','Y_STD')
			line = line.replace('cZ_ext_data_moy.','Z')
			line = line.replace('cZ_ext_data_ecart','Z_STD')			

			line =  [name.strip() for name in line.split('\t')]                 # It splits line data where there is a space (tab) and also eliminates the spaces after or before each new splitted element. The result is a list of elements

			#Headers = line[1:-1]                                                # It creates a list with the headers (it ignores the first array "Temps" and the last array -empty array-)            
			Headers = line[1:]            

			line = file_object.readline()                                       # Goes to next line (the line with units)
			line = file_object.readline()                                       # Goes to next line (this ignore the line with units)

			while line.strip():                                                 # This keeps advancing until a blank line is found (end of measurement sampling)
				line = line.replace(',','.')                                    # It changes each comma by a dot
				line =  [name.strip() for name in line.split('\t')]             # It splits line data where there is a space (tab) and also eliminates the spaces after or before each new element.The result is a list of measurements.
				DATA.append(line[1:])                                           # It sends each line of time-data to the DATA output list (also, it ignores the fist array of the line, i.e., "Temps")                 
				line = file_object.readline()                                   # It goes to the next line to keep advancing until the line with a blank line is found (end of data sampling)

	#DATA = np.asarray(DATA,dtype=np.float32)                                    # This converts a list into a numpy array
	#Headers = np.asarray(Headers)   

	#if IgnoreFirstLine==1:
	#	PandasDATA = PandasDATA.drop([0])
	
	return DATA, Headers

