# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                  OpenFOAM reader                 #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads data from Open Foam files.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## FLUENT CAS READER FUNCTION ########################################
############################################################################################################

def Reader_OpenFOAM(INPUT,Ps0,Pt0,TypeOfParameter):
	import numpy as np

	# Reading aero data from Open Foam file:
	POINTS = INPUT.Points   										                    # It takes the points coordinates
	Ps = INPUT.PointData["p"]                                                           # Static pressure [Pa]
	Vx = INPUT.PointData["U"][:,0]									                    # Velocity component along X-axis [m/s]	
	Vy = INPUT.PointData["U"][:,1]									                    # Velocity component along Y-axis [m/s]	
	Vz = INPUT.PointData["U"][:,2]									                    # Velocity component along Z-axis [m/s]	
	

	# Read static temperature data:
	if INPUT.GetPointData().HasArray("T")==0:                                           # This check if "T" array does not exists in the input 
		Ts = 'None'
	else:
		Ts = INPUT.PointData["T"]                                                       # If the array exists, then reads the array data directly from input
		
	Rho = 'None'	 
	MU_LAM = 'None'
	MU_TURB = INPUT.PointData["nut"]    							                    # Turbulent viscosity [Kg/m*s]

    
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			        	            # Velocity vector in the mesh reference frame [m/s]
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("vorticity")==0:                                   # This check if "VORTICITY" array does not exists in the input 
		VORTICITY = 'None'
	else:
		VORTICITY = INPUT.PointData["vorticity"]                                        # Vorticity vector in the mesh reference frame [1/s]

	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY