# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                SU2 format reader                 #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from a SU2 file format


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
############################################ SU2 READER FUNCTION ###########################################
############################################################################################################

def Reader_SU2(INPUT,R,CvGas):
	
	POINTS = INPUT.Points   																	# It takes the points coordinates   																	# It takes the points coordinates
	Rho = INPUT.PointData["Density"]
	Energy = INPUT.PointData["Energy"]
	Momentum = INPUT.PointData["Momentum"]
	#Pressure = INPUT.PointData["Pressure"]
	#Temperature = INPUT.PointData["Temperature"]
	
	
	Vx = Momentum[:,0]/Rho																		# Speed component along x-axis [m/s]
	Vy = Momentum[:,1]/Rho																		# Speed component along y-axis [m/s]
	Vz = Momentum[:,2]/Rho																		# Speed component along z-axis [m/s]
	V = algs.sqrt(Vx**2+Vy**2+Vz**2)
	eint = Energy/Rho
	Ts = (eint-0.5*V**2)/CvGas
	Ps = Rho*R*Ts
	MU_LAM = (0.000001458*Ts**1.5)/(Ts+110.4)   												# Two-coefficient Sutherland equation
	
	
	# Read turbulence data:
	if INPUT.GetPointData().HasArray("Eddy_Viscosity")==0:                                      # This check if "Eddy_Viscosity" array does not exists in the input 
		MU_TURB = 'None'
	else:
		MU_TURB = INPUT.PointData["Eddy_Viscosity"]                                             # If the array exists, then reads the array data directly from input
	
	

	
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			        	                    # Velocity vector in the mesh reference frame [m/s]
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("VORTICITY")==0:                                       	# This check if "VORTICITY" array does not exists in the input 
		VORTICITY = 'None'
	else:
		VORTICITY = INPUT.PointData["VORTICITY"]                                                # Vorticity vector in the mesh reference frame [1/s]
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY