# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################                TAU tecplot reader                #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from a TAU Tecplot file.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
######################################## TAU Tecplot READER FUNCTION #######################################
############################################################################################################

def Reader_TAU_Tecplot(INPUT):
	
	
	# Reading aero data from TAU file:
	POINTS = INPUT.Points   																	# It takes the points coordinates
	Vx = INPUT.PointData["x_velocity"] 															# Speed component along x-axis [m/s]
	print ()
	
	# Read Y_VELOCITY data:
	if INPUT.GetPointData().HasArray("y_velocity")==0:                           				# This check if "Y_VELOCITY" array does not exists in the input                
		print ('# TAU: You are loading a 2D data (No Y_VELOCITY data available)')  				# It means that Y_VELOCITY array does not exists 
		Vy = 0*Vx                                                                				# If the array does not exists,it creates a null vector
	else:
		Vy = INPUT.PointData["y_velocity"]                                       				# If the array exists, then reads the array data directly from input
	
	
	# Read Z_VELOCITY data:
	if INPUT.GetPointData().HasArray("z_velocity")==0:                           				# This check if "Z_VELOCITY" array does not  exists in the input                
		print ('# TAU: You are loading a 2D data (No Z_VELOCITY data available)')       			# It means that Z_VELOCITY array does not exists 
		Vz = 0*Vx
	else:
		Vz = INPUT.PointData["z_velocity"]                                       				# If the array exists, then reads the array data directly from input
	
		
	# Read static pressure data:
	Ps = INPUT.PointData["pressure"]                                                            # Static pressure [Pa]
	
	
	# Read density data:
	if INPUT.GetPointData().HasArray("density")==0: 
		Rho = 'None'
	else:
		Rho = INPUT.PointData["density"]                                						# Density [Kg/m^3]
	
	
	# Read static temperature data:
	if INPUT.GetPointData().HasArray("temperature")==0:                                        	# This check if "TEMPERATURE" array does not exists in the input 
		Ts = 'None'
	else:
		Ts = INPUT.PointData["temperature"]                                                    	# If the array exists, then reads the array data directly from input
	 
	
	
	MU_LAM = INPUT.PointData["viscosity"] 														# Molecular viscosity [Kg/m*s]
	MU_TURB = INPUT.PointData["eddy_viscosity"]                            						# Turbulent viscosity [Kg/m*s]	
	
	
	
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			        	                    # Velocity vector in the mesh reference frame [m/s]
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("VORTICITY")==0:                                       	# This check if "VORTICITY" array does not exists in the input 
		VORTICITY = 'None'
	else:
		VORTICITY = INPUT.PointData["VORTICITY"]                                                # Vorticity vector in the mesh reference frame [1/s]                       
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY