# -*- coding: utf-8 -*-
"""
############################################################################################################
#############################                     EPSILON                      #############################
#############################             elsA Tecplot Binary reader           #############################
############################################################################################################

# Abstract:
This python code is a module of the "Epsilon Aero Data" plugin that reads some variables from a elsA file
exported into the Tecplot Binary format.


# Disclaimer:
This plugin was developed for research purposes and released under GNU GPL V3 license without any guarantee
of any kind, either express or implied. Its use for teaching, research and industrial applications is allowed
under the strict responsibility of the user. The authors of this plugin are not responsible for any damages
or errors related to the use of the plugin.
"""


############################################################################################################
############################################### MODULES LOAD ###############################################
############################################################################################################

# We load the Python and Paraview standard modules:
import numpy as np
import vtk
from vtk.numpy_interface import algorithms as algs


############################################################################################################
################################### ELSA TECPLOT BINARY READER FUNCTION ####################################
############################################################################################################

def Reader_elsA_Tecplot_Binary(INPUT,R,CvGas):
	
	# Reading aero data from Fluent file:
	POINTS = INPUT.Points   										# It takes the points coordinates
	Rho = INPUT.PointData["ro"]                              		# Density [Kg/m^3]
	rovx = INPUT.PointData["rovx"]                              	# Density*Speed component along x-axis [kg/m2s]	
	rovy = INPUT.PointData["rovy"]
	rovz = INPUT.PointData["rovz"]
	roE = INPUT.PointData["roE"]   									# Density*Energy  
	rok = INPUT.PointData["rok"]   									# Density*Kinetic energy
	roeps = INPUT.PointData["roeps"]    							# Density*Epsilon
	
	Vx = rovx/Rho
	Vy = rovy/Rho
	Vz = rovz/Rho
	V = algs.sqrt(Vx**2+Vy**2+Vz**2)
    
	eint = roE/Rho
	Ts = (eint-0.5*V**2)/CvGas
	Ps = Rho*R*Ts
	MU_LAM = (0.000001458*Ts**1.5)/(Ts+110.4)   					# Two-coefficient Sutherland equation
	MU_TURB = 0.09*Rho*(rok/Rho)**2/(roeps/Rho)

	
	Velocity_Vector = algs.make_vector(Vx,Vy,Vz)    			    # Velocity vector in the mesh reference frame [m/s]
	
	# Read vorticity data:
	if INPUT.GetPointData().HasArray("VORTICITY")==1:               # This check if "VORTICITY" array exists at the input 
		VORTICITY = INPUT.PointData["VORTICITY"]                    # Vorticity vector in the mesh reference frame [1/s]
	else:
		VORTICITY = 'None'                            				 
	
	
	return POINTS,Ps,Ts,Rho,MU_LAM,MU_TURB,Velocity_Vector,VORTICITY